# conda-forge-metadata
[![tests](https://github.com/regro/conda-forge-metadata/actions/workflows/tests.yml/badge.svg)](https://github.com/regro/conda-forge-metadata/actions/workflows/tests.yml)
[![Publish to PyPI](https://github.com/regro/conda-forge-metadata/actions/workflows/pypi.yml/badge.svg)](https://github.com/regro/conda-forge-metadata/actions/workflows/pypi.yml)

programatic access to conda-forge's metadata
